Looking at the directory structure you provided...

```
├── from
│   ├── v1
│   │   └── types.proto
│   └── yetanother
│       └── v1
│           └── types.proto
└── to
    └── v1
        └── user.proto
```

with the following packages:
- `from/v1`: fv1
- `from/yetanother/v1`: yav1
- `to/v1`: tv1


which, as a result of the build script, then results in:

```
├── from
│   ├── v1
│   │   ├── types.pb.go
│   │   ├── types.pb.validate.go
│   │   └── types.proto
│   └── yetanother
│       └── v1
│           ├── types.pb.go
│           ├── types.pb.validate.go
│           └── types.proto
└── to
    └── v1
        ├── user.pb.go
        ├── user.pb.validate.go
        └── user.proto
```

modifying the structure of your project a touch. The package structure is
well-defined.

```
├── buf.gen.yaml
├── buf.work.yaml
└── proto
    ├── buf.yaml
    ├── bar
    │   └── v1
    │       └── types.proto
    ├── foo
    │   └── v1
    │       └── types.proto
    └── user
        └── v1
            └── user.proto
```

and the `user.proto` file can now import like this:

```protobuf
syntax = "proto3";

package user.v1;

import "foo/v1/types.proto";
import "bar/v1/types.proto";
import "validate/validate.proto";

message UserInfo {
    foo.v1.ReportStatus s1 = 1 [(validate.rules).enum.defined_only = true];
    bar.v1.OtherReportStatus s2 = 2 [(validate.rules).enum.defined_only = true];
}
```

After telling buf to output to a `/gen` directory, the result is now:

```
└── gen
    ├── bar
    │   └── v1
    │       ├── types.pb.go
    │       └── types.pb.validate.go
    ├── foo
    │   └── v1
    │       ├── types.pb.go
    │       └── types.pb.validate.go
    └── user
        └── v1
            ├── user.pb.go
            └── user.pb.validate.go
```

and our user.pb.validate is correctly formed:

```go
package userv1

import (
	...
	barv1 "github.com/valtest/gen/bar/v1"

	foov1 "github.com/valtest/gen/foo/v1"
	...
)
var (
	_ = barv1.OtherReportStatus(0)

	_ = foov1.ReportStatus(0)
)
func (m *UserInfo) validate(all bool) error {

	if _, ok := foov1.ReportStatus_name[int32(m.GetS1())]; !ok {
                ...
	}

	if _, ok := barv1.OtherReportStatus_name[int32(m.GetS2())]; !ok {
		...
	}
}
```
